@@ -60,6 +60,31 @@ try:
     print(jesus)
 except ValidationError as ex:
     print(ex)
+    print(ex.payload)
 
 # try to adding a missing keyword:
-jesus = User(airport=True)
+try:
+    jesus = User(airport=True)
+except ValidationError as ex:
+    print(ex)
+except TypeError as ex:
+    print(ex)
+
+class Animal(BaseModel):
+    name: str
+    specie: str
+    age: int
+
+try:
+    animal = Animal(**{
+        "name": "Human",
+        "specie": "Homo Sapiens",
+        "age": "otra verga"
+    })
+except ValidationError as ex:
+    print(ex)
+    print(ex.payload)
+except TypeError as ex:
+    print(ex)
+except ValueError as ex:
+    print(ex)
